/*
 * test program for the configuration parser unit
 *
 * This file is part of the backconn project. http://backconn.sourceforge.net
 * Copyright (C) 2017, 2018 Mateusz Viste
 *
 * ===================== PUBLISHED UNDER THE MIT LICENSE =====================
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 * ===========================================================================
 */

#include <stdio.h>

#include "config.h"

int main(int argc, char **argv) {
  struct scfg *cfg;
  FILE *fp;
  char *fname;

  if (argc != 2) {
    printf("usage: config_test config.cfg\n");
    return(1);
  }

  fname = argv[1];

  printf("opening file '%s'... ", fname);
  fp = fopen(fname, "r");
  if (fp == NULL) {
    printf("\nERROR: fopen() failure on '%s'\n", fname);
    return(1);
  }
  printf("ok\n");

  cfg = config_read(fp);
  fclose(fp);

  if (cfg == NULL) {
    printf("\nERROR: no configurations found in file '%s'\n", fname);
    return(1);
  }

  printf("=== config dump ===\n");
  while (cfg != NULL) {
    printf("'%s'", cfg->token);
    if (cfg->val[0] != NULL) {
      int i;
      printf(" ->");
      for (i = 0; i < 4; i++) {
        if (cfg->val[i] != NULL) printf(" '%s'", cfg->val[i]);
      }
    }
    printf("\n");
    cfg = cfg->next;
  }
  printf("===================\n");

  return(0);
}
